WorkspaceShape

Struct WorkspaceShape 

pub struct WorkspaceShape {
    pub shape: Shape,
    pub dimension: Option<String>,
}
Describe the shape of the workspace.

Fields

shape: Shape

All actors accessing the workspace.

dimension: Option<String>

Starting dimension in the shape denoting all ranks that share the same workspace.

Implementations

Source

impl WorkspaceShape

pub fn owners(&self) -> Result<Shape, ShapeError>

Reduce the shape to contain only the “owners” of the remote workspace

This is relevant when e.g. multiple worker on the same host share a workspace, in which case, we’ll reduce the share to only contain one worker per workspace, so that we don’t have multiple workers trying to sync to the same workspace at the same time.

pub fn downstream(&self, rank: usize) -> Result<Shape>

Return a new shape that contains all ranks that share the same workspace with the given “owning” rank.

Errors

Returns an error if the given rank’s coordinates aren’t all zero starting at the specified dimension and continuing until the end. For example, if the dimension is Some(“host”), then the coordinates for the rank must be 0 in the host dimension and all subsequent dimensions.